#!/bin/bash

set -o errexit
set -o nounset
set -o pipefail

# source ./vm_env.sh
source ./aid/log.sh
source ./common.sh

app_file="./mu1-to-mu2-develop/conf/app.toml"

Prepare_app_toml_mu() {

  cat <<EOF >>$app_file
[global]
[global.admin_user]
# 用于插入creator字段
admin_user_name="multiverse"

[global.schemas]
# mu1 mu2的DB需要在同一Mysql下
mu1_upm_schema_name="upm_mu1"
mu1_specmgmt_schema_name="specmgmt_mu1"
mu1_automation_schema_name="automation_mu1"
mu1_codvmware_schema_name="cod-vmware_mu1"
mu1_prc_schema_name="db_prc_mu1"
mu1_datagov_schema_name="datagov_mu1"
mu1_apigov_schema_name="apigov_mu1"
mu1_skm_schema_name="skm_mu1"
mu1_vault_schema_name="vault_mu1"
mu1_soc_schema_name="soc_mu1"

mu2_upm_schema_name="upm"
mu2_environment_schema_name="environment"
mu2_workspace_schema_name="workspace"
mu2_automation_schema_name="automation"
mu2_cod_schema_name="cpc"
mu2_prc_schema_name="db_prc"
mu2_organization_schema_name="organization"
mu2_project_schema_name="project"
mu2_workflow_schema_name="workflow"
mu2_permission_schema_name="permission"
mu2_cicd_schema_name="cicd"
mu2_skm_schema_name ="skm" # skm target db name
mu2_vault_schema_name="vault"
mu2_soc_schema_name="soc"

[global.cicd_tool]
cicd_tool_id="$(Get_app_values .mumpv2.cicd_tool_id)"
EOF
}

Prepare_app_toml_tenant() {
  tn_length=$(Get_json_length ".tenant")
  tn_list=""

  #get tenant list
  if [ $tn_length ] >1; then
    tn_length=$(($tn_length - 1))

    for i in $(seq 0 $tn_length); do
      migration::log::info "tenant index: $i"

      # tenantname
      # if [ $i ]
      #    tn_list = ${tn_list}$(Get_app_values .tenant[$i].tenantcode)
      #    tn_list = ${tn_list}$(Get_app_values .tenant[$i].tenantcode)
      if [ $i -ne 0 ]; then
        tn_list=${tn_list}\",\"$(Get_app_values .tenant[$i].tenantname)
        migration::log::info $tn_list
      else
        tn_list="$(Get_app_values .tenant[$i].tenantname)"
        migration::log::info "tenant list: $tn_list"
      fi
    done
  else
    migration::log::info "Pls input tenant info to json file."
  fi
  migration::log::info "tenant list: [$tn_list]"
  cat <<EOF >>$app_file
[global.tenant]
#列出所有要迁移的tenant
list = ["$tn_list"]
EOF
  #get wks list
  tenant_code=""
  tenant_name=""
  # wks_list=""
  # env_list=""

  # tn_length=0
  for i in $(seq 0 $tn_length); do
    wks_list=""
    env_list=""
    wks_length=$(Get_json_length ".tenant[$i].wks")
    env_length=$(Get_json_length ".tenant[$i].env")
    migration::log::info "workspace length: $wks_length"
    # if [ $wks_length -eq 0 ] || [ $env_length -eq 0 ]; then
    if [ $wks_length -eq 0 ]; then
      migration::log::info "Pls input wks/env info to json file."
      exit 1
    fi
    tenant_code=$(Get_app_values .tenant[$i].tenantcode)
    tenant_name=$(Get_app_values .tenant[$i].tenantname)
    wks_list=$(Get_app_values ".tenant[$i].wks[0].wksname")
    if [ $env_length -gt 0 ]; then
    env_list=$(Get_app_values ".tenant[$i].env[0].envname")
    fi
    if [ $wks_length -gt 1 ] ; then
      for n in $(seq 1 $(($wks_length - 1))); do
        wks_list=${wks_list}\",\"$(Get_app_values ".tenant[$i].wks[$n].wksname")
      done
    fi
    if [ $env_length -gt 1 ]; then
      for n in $(seq 1 $(($env_length - 1))); do
        env_list=${env_list}\",\"$(Get_app_values ".tenant[$i].env[$n].envname")
      done
    fi

    migration::log::info "workspace list: $wks_list"
    migration::log::info "environment list: $env_list"
    migration::log::info "workspace list: $wks_list"
    cat <<EOF >>$app_file
[global.tenant.$tenant_name]
#mu1
tenant_code="$tenant_code"
#设置mu2 org name
name="$tenant_name"
#设置mu2 org id
organization_id="org00000$(($i + 1))"
workflow_id="wkf00000$(($i + 1))"
#列出该tenant所有要迁移的wks
wks_list=["$wks_list"]
EOF

if [ $env_length -eq 0 ];then
    cat <<EOF >>$app_file
#列出该tenant所有要迁移的env
env_list=[]
EOF
else
    cat <<EOF >>$app_file
#列出该tenant所有要迁移的env
env_list=["$env_list"]
[global.tenant.$tenant_name.wks]
EOF
fi

    # if [ $tn_length -gt 1 ]; then

    for n in $(seq 0 $(($wks_length - 1))); do
      wks_name=$(Get_app_values ".tenant[$i].wks[$n].wksname")
      wks_id=$(Get_app_values ".tenant[$i].wks[$n].wks_code")
      cat <<EOF >>$app_file
[global.tenant.$tenant_name.wks.$wks_name]
wks_code="$wks_id"
#设置给mu2的wks/program/project/env_phase 需要跟mu1一样,建git仓库会查数据库去处理
wks_name="$wks_name"
program_code="$(echo $wks_id | sed 's/WS0/SPG/g')"
project_code="$(echo $wks_id | sed 's/WS0/SPJ/g')"
EOF
    done

    cat <<EOF >>$app_file
[global.tenant.$tenant_name.env]
EOF
    if [ $env_length ] >0; then

      for n in $(seq 0 $(($env_length - 1))); do
        env_name=$(Get_app_values ".tenant[$i].env[$n].envname")
        env_id=$(Get_app_values ".tenant[$i].env[$n].env_code")
        wks_id=$(Get_app_values ".tenant[$i].env[$n].wks_code")

        cat <<EOF >>$app_file

[global.tenant.$tenant_name.env.$env_name]
env_code="$env_id"
wks_code="$wks_id"
env_phase = "Sit"
EOF
      done
    fi
  done

}

Prepare_app_toml_mu2() {
  # Get_app_values ".tenant[$i].wks[$n].wksname"
  cat <<EOF >>$app_file
[gitlab]
url = "$(Get_app_values ".mumpv2.gitlaburl")"
private_token = "$(Get_app_values ".mumpv2.gitlabtoken")"
group = ""

#MU2环境信息,redis
[redis]
addr = "$(Get_app_values ".mu2_k8s_master"):$(Get_app_values ".redis.redisport")"
user = ""
pwd = "$(Get_app_values ".redis.redispwd")"
#mu1-to-mu2
#MU2环境信息,db
[db]
type = "mysql"
addr = "$(Get_app_values ".mumpv2.dbaddr")"
user = "$(Get_app_values ".mumpv2.dbuser")"
password = "$(Get_app_values ".mumpv2.dbpwd")"
database = "$(Get_app_values ".mumpv2.dbdatabase")"
params = "?charset=utf8&loc=Local"
debug = false
[db.pool]
maxIdleConns = 30
maxOpenConns = 30
maxIdleTime = 30
maxLifeValue = 9000

[upm]
upmbss01_name="upmbss01"
upmbss01_version="39-feature-password-compatible"
upmbss01_config_name = "upmbss01-config" # skm deployed in k8s configmap name
upm_namespace = "default" # skm deploy in k8s namespace
upmbss01_new_downstream_replacement_file_path="./data/upm/upmbss01/upmbss01_new_downstream_replacement.toml"
upmbss01_replacement_target_content_file_path="./data/upm/upmbss01/upmbss01_replacement_target_content.toml"
mu2_pem_session_vpn_name="multiverse"
mu2_pem_session_user_name="multiverse"
mu2_pem_session_password_name="multiverse"
mu2_pem_session_host="tcp:$(Get_app_values ".mumpv2.solaceaddr")"
mu2_org="TN000000"
mu2_workspace="WS000000"
mu2_environment="EV000000"
mu2_az="AZ000000"
mu2_su="SU000000"

[prc]
[prc.kvs]
time_zone="$(Get_app_values ".timezone")"

[automation]
automation_service_name="automation"
automation_service_version="385-feature-upgrade-improve"
automation_namespace="default"

[environment]
environment_version="2656-feature-upgrade-improve "
mu_web_service_version="2.2.13"
environment_service_name="environment"
environment_namespace="default"
mu_web_service_name="mu-web"
mu_web_namespace="default"
EOF
}
Prepare_app_toml_runtime() {
  cat <<EOF >>$app_file
[environment.gls]
mu1_majmad_new_version="0.5.12"
mu1_minmad_new_version="0.5.12"
mu1_majtrd_image_name="majtrd"
mu1_mintrd_image_name="mintrd"
mu1_majtrd_response_data_key = "response"
mu1_majtrd_response_error_code_key = "errorCode"
mu1_majtrd_response_error_msg_key = "errorMsg"
mu1_majtrd_response_template = "{\"code\":\"{{.errorCode}}\", \"message\":\"{{.errorMsg}}\", \"response\":{{.data}},\"debugStack\":\"{{.errorStack}}\"}"

[environment.e_runtime_config]
appDeployMode="InChain"
appRunningMode="ContinuousRun"
serviceLogMaxBackups="7"
serviceLogMaxDays="7"
serviceLogMaxSize="20"
[environment.e_environment_config]
aigLogConsole = "true"
aigLogLevel = "debug"
aigLogMaxBackups = "7"
aigLogMaxDays = "7"
aigLogMaxSize = "20"
aogLogConsole = "true"
aogLogLevel = "debug"
aogLogMaxBackups = "7"
aogLogMaxDays = "7"
aogLogMaxSize = "20"
apiCheckType = "path"
apmEnable = "true"
apmPrintEmptyTraceIdRecordAtClientSide = "true"
apmVersion = "v2"
appImagePullPolicy = "IfNotPresent"
appLimitsCpu = "0.1"
appLimitsMemory = "0.2"
appRequestsCpu = "0.01"
appRequestsMemory = "0.02"
callbackChanSize = "1024"
callbackFastFailed = "true"
callbackParallelNumber = "128"
callbackTimeoutMilliseconds = "60000"
cleanupUserStatusEventId = "AIGCleanUpUserStatus"
clientSideStatusFSM = "true"
createSessionEventId = "AIGCreateSession"
designConsistencyCheck = "false"
disableGLSLookupOptimization = "false"
disableHeaderNamesNormalizing = "false"
dmqEligible = "false"
enableApiAuthCheck = "true"
enableAppendGlobalTxnIdToTopic = "false"
enableAuthorizationAccountName = "false"
enableCircuitBreaker = "true"
enableClientHealthStatCheck = "true"
enableErrorCode = "true"
enableIPBlackList = "false"
enableIPWhiteList = "false"
enableSecure = "false"
errorResponseTemplate = "{\"code\":\"{{.errorCode}}\", \"message\":\"{{.errorMsg}}\", \"response\":{{.data}}}"
eventId = "UPMRefreshToken"
eventType = "TRN"
expTime = "900"
globalHeaders = "{\"Content-Security-Policy\":\"default-src 'self'; img-src 'self'; object-src 'none'; script-src 'self'; style-src 'self'; frame-ancestors 'self'; base-uri 'self'; form-action 'self';\", \"X-Content-Type-Options\":\"nosniff\", \"Strict-Transport-Security\":\"max-age=31536000; includeSubdomains;\",\"Cache-Control\":\"no-cache,no-store\", \"Access-Control-Allow-Origin\":\"*\", \"Access-Control-Allow-Credentials\":\"true\"}"
glsflag = "0"
harborDomain = "hub.multiverse.io"
idXxx = "utf8_bin"
isHealthCheck = "false"
isRelease = "false"
isUpload = "false"
lookupEnable = "false"
maskRule = ""
maxDeliverMessageMESHCostMilliseconds = "2000"
maxHeaderKeyLength = "256"
maxHeaderValueLength = "1024"
maxPublishMessageInternalCostMilliseconds = "1000"
maxReadTimeoutMilliseconds = "8000"
maxRequestBodySizeMb = "100"
maxRequestPerSeconds = "100"
maxRetryTimes = "1"
maxServerStopTimeoutSeconds = "30"
maxSessionPerAccount = "1"
maxThreadNumberOfReplyChannel = "8"
maxThreadNumberOfSender = "512"
maxTimeOutMillisecond = "30000"
maxTps = ""
maxWaitingTime = "30000"
maxWaittingTime = "30000"
maxWriteTimeoutMilliseconds = "80000"
minTimeoutMilliseconds = "15000"
mockBody = ""
mockEnable = "false"
mysqlDebug = "true"
mysqlMaxIdleConns = "1000"
mysqlMaxLifeValue = "300"
mysqlMaxLimitValue = "50000"
mysqlMaxOpenConns = "1000"
mysqlMaxQuery = "30"
mysqlParams = "?charset=utf8&loc=Local"
parseDownstream = "false"
persistentDeliveryMode = "false"
podReplicas = "1"
printPayload = "false"
receiveMsgBufferSize = "1"
redisPoolSize = "10"
redisReadonly = "false"
replyChannelNum = "1024"
requireLogin = "true"
responseDataKey = "response"
responseErrorCodeKey = "code"
responseErrorMsgKey = "message"
responseTemplate = "{\"code\":\"{{.errorCode}}\", \"message\":\"{{.errorMsg}}\", \"data\":{{.data}}}"
responseType = "json"
retryIntervalTime = "100"
retryWatting = "0"
sedImagePullPolicy = "IfNotPresent"
sedLimitsCpu = "0.1"
sedLimitsMemory = "0.2"
sedLogConsole = "true"
sedLogLevel = "error"
sedLogMaxBackups = "7"
sedLogMaxDays = "7"
sedLogMaxSize = "20"
sedRequestsCpu = "0.01"
sedRequestsMemory = "0.02"
sedVersion = "0.2.8"
sendRequestReplyTimeoutMilliseconds = "60000"
serviceImage = "multiverse"
serviceLogConsole = "true"
serviceLogLevel = "info"
serviceLogMaskRules = ""
serviceLogMaxBackups = "7"
serviceLogMaxDays = "7"
serviceLogMaxSize = "20"
sessionHashSalt = "*37\$nxlq3;:'[]mcbiwlie"
sidKey = "sid"
suId = ""
successResponseTemplate = "{{.data}}"
timeoutMilliseconds = "30000"
updateUserInfoEventId = "AIGUpdateUserInfo"
uploadFileMax = "20"
uploadFileMaxSize = "0"
uploadFileType = "jepg,pdf"
upmLogoutPath = "/upm/v1/logout"
EOF
}

Prepare_app_toml_muskm() {
  cat <<EOF >>$app_file

[skm]
#写mu2的
skm_name = "skm"  #skm k8s pod name
skm_config_name = "skm-skm-config" # skm deployed in k8s configmap name
skm_vault_config_name = "skm-vault-config" # vault deployed in k8s configmap name
skm_namespace = "default" # skm deploy in k8s namespace
#写mu1的
vault_key_1 = "$(Get_app_values .muskm.vaultkey01)" # deployed vault key1 this for unlock vault
vault_key_2 = "$(Get_app_values .muskm.vaultkey02)" # deployed vault key2 this for unlock vault
vault_key_3 = "$(Get_app_values .muskm.vaultkey03)+7jq" # deployed vault key3 this for unlock vault
vault_token = "$(Get_app_values .muskm.vaulttoken)" # skm connect vault token  this value config in skm app.toml

#业务集群skm迁移相关
[skm.environment]
# target_environment_dbname="environment" # environment db name,使用mu2_environment_schema_name
EOF
}

Prepare_app_toml_skm() {
  skm_length=$(Get_json_length ".skmsvc")
  migration::log::info "skm length: $skm_length"
  skm_list=$(Get_app_values ".skmsvc[0].skm_name")
  # if [ $skm_length ] >1; then
  #   for n in $(seq 1 $(($skm_length - 1))); do
  #     skm_list=$skm_list",""$(Get_app_values ".skmsvc[$n].skm_name")"
  #   done
  # fi
  # migration::log::info "skm length: $skm_length"
  # migration::log::info "skm list: $skm_list"

  clusterid=""
  if [ $skm_length -gt 0 ]; then
    skm_length=$(($skm_length - 1))

    for i in $(seq 0 $skm_length); do
      migration::log::info "svc skm index: $i"

      # tenantname
      # if [ $i ]
      #    tn_list = ${tn_list}$(Get_app_values .tenant[$i].tenantcode)
      #    tn_list = ${tn_list}$(Get_app_values .tenant[$i].tenantcode)
      if [ $i -ne 0 ]; then
        skm_list=${skm_list}\",\"$(Get_app_values ".skmsvc[$n].skm_name")
        # migration::log::info $skm_list
      else
        skm_list="$(Get_app_values ".skmsvc[0].skm_name")"
        # migration::log::info "svc skm list: $skm_list"
      fi
    done
  else
    migration::log::info "Pls input svc skm info to json file."
  fi
    migration::log::info "svc skm list: $skm_list"

    cat <<EOF >>$app_file  
# need migration skm cluster name
cluster_id=["${skm_list}"] 
EOF

    # skm_length=$(($skm_length - 1))
    for n in $(seq 0 $skm_length); do
  # for n in $(seq 0 $(($skm_length - 1))); do
    clusterid=$(Get_app_values ".skmsvc[$n].skm_name")
    migration::log::info "svc skm index: $n"
    migration::log::info "svc skm clusterid: $clusterid"

    cat <<EOF >>$app_file
[skm.environment.${clusterid}]
#写mu2纳管的业务的
env_code = "$(Get_app_values ".skmsvc[$n].env_code")"           #env code
tenant_code = "$(Get_app_values ".skmsvc[$n].tn_code")"        #tenant code
instance_num = 1                #deployed skm instance num this will for monitor skm cluster
#skm pod name
skm_code = "$(Get_app_values ".skmsvc[$n].skm_code")"            #deployed skm code ,get this value can use cmd:kubectl get pods -A|grep skm
#设置skm cluster id
skm_cluster_id = $(Get_app_values ".skmsvc[$n].skm_cluster_id")              #skm db Primary key ID this id will relation skm service
[skm.environment.${clusterid}.db]
type = "mysql"
addr = "$(Get_app_values ".skmsvc[$n].dbaddr")"
user = "$(Get_app_values ".skmsvc[$n].dbuser")"
password = "$(Get_app_values ".skmsvc[$n].dbpassword")"
database = "$(Get_app_values ".skmsvc[$n].dbname")"
mu1_business_skm_schema_name="$(Get_app_values .skmsvc[$n].dbname)"
params = "?charset=utf8&loc=Local"
debug = false
[skm.environment.${clusterid}.db.pool]
maxIdleConns = 30
maxOpenConns = 30
maxIdleTime = 30
maxLifeValue = 9000
EOF
  done
}

Prepare_app_toml_monitor() {
  cat <<EOF >>$app_file
#MU2 environment information
[monitoring]
rsquery_old_version="2.4.1"
rsquery_version="2.4.2"
asquery_old_version="2.4.0"
asquery_version="2.4.2-migration"
monitor_namespace="default"
monitor_service_name="statusmgmt-monitor"
monitor_service_version="2.4.3"

[monitoring.mu1]
[monitoring.mu1.elasticsearch]
urls = "$(Get_app_values ".mu1monitor.esurls")"
[monitoring.mu1.tdengine]
urls = "$(Get_app_values ".mu1monitor.tdurls")"
[monitoring.mu1.clickhouse]
urls = "$(Get_app_values ".mu1monitor.churls")"
EOF
}

>$app_file

# genatate mu1 mu2 db name
Prepare_app_toml_mu
# genatate mu1 tenant info
Prepare_app_toml_tenant
# genatate mu2 pass info
Prepare_app_toml_mu2
# genatate mu service runtime info
Prepare_app_toml_runtime
# genatate mvp1_2 skm info
Prepare_app_toml_muskm
# genatate svc skm info
Prepare_app_toml_skm
# genatate monitor pass info
Prepare_app_toml_monitor

migration::log::info "Genarate app.toml success, path:$app_file"

#4.2
migration::log::info "start build tools..."
sh ./build.sh
Get_Status $?

migration::log::info "Genarate build binary success."
