#!/bin/bash
set -o errexit
set -o nounset
set -o pipefail
migration_VERBOSE=5

source ./aid/log.sh
source ./operator.sh
source ./common.sh

if [ ! -f ./.status ]; then
    touch ./.status
fi

if [ $# -lt 1 ]; then
    echo "Usage: $0 [options]"
    echo ""
    echo "Options:"
    echo "  all,   execute all steps."
    echo "  retry, retry when failed."
    echo "  rollback, rollback when failed."
    exit 0
fi

if [[ $1 == "rollback" ]]; then
    {
        migration::log::info "start mvp2 service rollback..."
        rollback_all_upgrade_services
    }
fi
if [[ $1 == "all" && $(cat ./.status) -eq 1 ]]; then
    # refresh 03.main.sh
    sed -i "s/^###//g" 03.main.sh
    echo 0 >./.status

    echo "Pls retry..." && exit 0
else
    # Reset flag
    echo 1 >./.status
fi

# echo "test....." && exit 0

Home=$(dirname "$(realpath "$0")")
Cmd_dir="${Home}/mu1-to-mu2-develop/cmd"

# 2.2 redis
migration::log::info "start create redis svc..."
Upgrade_redis_svc
Get_Status $?

# 3.2 UPM service upm1000001
# 3.7 soc Solace Add queue and topic -> 更新 mvp2 soc helm 包

migration::log::info "start mvp2 service..."
###Upgrade_mvp2_service
Get_Status $? Upgrade_mvp2_service

#4.2 build binary mvoe to prpare steps.

#prepare step, ignore.s
: ' 
# --------------------------
# cd /data
# obsutil cp obs://mu-warehouse/apps/multiverse/automation/release4/ansible/down/cod_package/ansible_mvp2_all_20240813.tgz .
# tar -xvf ansible_mvp2_all_20240813.tgz
'

#prepare step, ignore.
: ' 
scp xxx:/data/mvp2-operator.zip /data
scp xxx:/data/mu1-to-mu2-develop-cmd-resource.tar.gz /data
cd /data/
tar -xvf mu1-to-mu2-develop-cmd-resource.tar.gz
mkdir /data/mu1-to-mu2-develop-cmd-resource/cmd/resource/ansible/down

unzip mvp2-operator.zip -d /data/mu1-to-mu2-develop-cmd-resource/cmd/resource/ansible/down
cd /data/mu1-to-mu2-develop-cmd-resource/cmd/resource
----------------------------
'

# chmod +x operator-migration.sh
# ./operator-migration.sh role ip_list
#role: [dos-binary-operator|ems-binary-operator|rbo
#role rbo|dbo|ebo

###Upgrade_res_agent
Get_Status $? Upgrade_res_agent

migration::log::info "start upgrade the soc-k8s-agent" # 6.5 upgrade the soc-k8s-agent
###Upgrade_k8s_agent
Get_Status $? Upgrade_k8s_agent

#8.2,8.3
cd ${Home}
migration::log::info "start mvp1 sql migration..."
###Migration_mvp1_mudb_mvp2
Get_Status $? Migration_mvp1_mudb_mvp2

#echo 9.1-7
migration::log::info "start mvp2 migration workspace..."
###Migration_mvp2_service_workspace
Get_Status $? Migration_mvp2_service_workspace

migration::log::info "start mvp2 migration upm..."
###Migration_mvp2_service_upm
Get_Status $? Migration_mvp2_service_upm

migration::log::info "start mvp2 migration muskm..."
###Migration_mvp2_service_muskm
Get_Status $? Migration_mvp2_service_muskm

migration::log::info "start mvp2 migration svcskm..."
###Migration_mvp2_service_svcskm
Get_Status $? Migration_mvp2_service_svcskm

migration::log::info "start mvp2 migration cod..."
###Migration_mvp2_service_cod
Get_Status $? Migration_mvp2_service_cod

migration::log::info "start mvp2 migration prc..."
###Migration_mvp2_service_prc
Get_Status $? Migration_mvp2_service_prc

migration::log::info "start mvp2 migration soc..."
###Migration_mvp2_service_soc
Get_Status $? Migration_mvp2_service_soc

migration::log::info "start mvp2 migration automation..."
###Migration_mvp2_service_automation
Get_Status $? Migration_mvp2_service_automation

migration::log::info "start mvp2 migration environment..."
###Migration_mvp2_service_environment
Get_Status $? Migration_mvp2_service_environment

migration::log::info "start mvp2 migration monitoring..."
###Migration_mvp2_service_monitoring
Get_Status $? Migration_mvp2_service_monitoring


#9.8
migration::log::info "start set soc replice to 0"
ssh ${mu1_k8s_master} "${kubectl} scale sts soc --replicas=0"
Get_Status $?

#10.1-6
# 业务侧的gls更新, 另外走一个CR

#10.7 Modify mvp2 mu gls topic -> 更新mu2 部署脚本
