#!/bin/bash

# 日志级别
LOG_LEVELS="INFO ERROR DEBUG"

# 日志文件
LOG_FILE="../main.log"

# 检查日志文件是否存在，不存在则创建
if [ ! -f "$LOG_FILE" ]; then
    touch "$LOG_FILE"
fi

# 日志函数
log() {
    local level="$1"
    local message="$2"

    # 检查日志级别是否合法
    if [[ ! " ${LOG_LEVELS} " =~ " ${level} " ]]; then
        echo "Invalid log level: ${level}"
        return 1
    fi
    if [ ${level} == "ERROR" ];then
        level=$(echo -e "[\033[31mError\033[0m]")
        else
        level=$(echo -e "[\033[32mInfo\033[0m]")
    fi
    # 获取当前时间
    local timestamp=$(date '+%Y-%m-%d %H:%M:%S')

    # 构建日志信息
    local log_message="${timestamp} [${level}] ${message}"

    # 将日志信息输出到控制台和文件
    echo "$log_message"
    echo "$log_message" >> "$LOG_FILE"
}

# 使用日志函数
# log "INFO" "This is an informational message."
# log "ERROR" "This is an error message."
# log "DEBUG" "This is a debug message." >> "$LOG_FILE"