#!/bin/bash
set -o errexit
set -o nounset
set -o pipefail

source ./common.sh

Home=$(dirname "$(realpath "$0")")
Cmd_dir="${Home}/mu1-to-mu2-develop/cmd"
Cmd_dir2="${Home}/mu1-to-mu2-develop"

Upgrade_redis_svc() {
    scp ./yaml/mvp1/redissvc.yaml ${mu2_k8s_master}:/tmp
    # ssh ${mu2_k8s_master} "${kubectl} delete -f /tmp/redissvc.yaml"
    ssh ${mu2_k8s_master} "${kubectl} apply -f /tmp/redissvc.yaml"
}

Upgrade_k8s_agent() {
    if [ ! -z "${k8s_cluster}" ]; then
        
        migration::log::info "k8s cluster list: ${k8s_cluster}."
        for i in ${k8s_cluster}; do
            # ssh $i "${kubectl} set image statefulset/soc-k8s-agent soc-k8s-agent=hub.multiverse.io/multiverse/soc:2.1.0 -n multiverse"
            ssh $i "${kubectl} set image statefulset/soc-k8s-agent soc-k8s-agent=hub.multiverse.io/the-platform-resource/soc:2.1.0 -n multiverse"
            # ${kubectl} rollout undo statefulset/soc-k8s-agent -n multiverse --to-revision=last_one
        done
    else
        migration::log::info "No service k8s cluster."
    fi
}

Upgrade_mvp2_service() {

    cd ${Cmd_dir2}
    ./cmd/upm/upm_migration.sh upgrade_services
    # ./cmd/upm/upm_migration.sh rollback_upgrade_services
    cd ${Cmd_dir2}
    sh ./cmd/automation/automation_migration.sh upgrade_services
    cd ${Cmd_dir2}
    ./cmd/environment/environment_migration.sh upgrade_services
    cd ${Cmd_dir2}
    sh ./cmd/monitoring/2.monitoring_configmap_migration.sh handle
    # ./cmd/monitoring/2.monitoring_configmap_migration.sh rollback
}

Upgrade_prc_agent() {
    cd ${Cmd_dir}/resource
    variable=$1
    case $variable in
    dos-binary-operator | ems-binary-operator | rbo)
        ./operator-migration.sh "$variable" "${2}"
        ;;
    *)
        echo "usage: ./operator-migration.sh aget_role ip_list"
        ;;
    esac
}

Migration_mvp2_service_workspace() {
    #9.1
    cd ${Cmd_dir2}
    # ./cmd/workspace/workspace_migration.sh rollback
    ./cmd/workspace/workspace_migration.sh handle

}
Migration_mvp2_service_upm() {
    #9.2
    cd ${Cmd_dir2}
    # ./cmd/upm/upm_migration.sh upgrade_services
    ./cmd/upm/upm_migration.sh handle
    # ./cmd/upm/upm_migration.sh rollback
}
Migration_mvp2_service_muskm() {
    #9.3
    cd ${Cmd_dir2}
    # ./cmd/skm/1.mu_skm_migration.sh rollback
    # ./cmd/skm/2.mu_skm_configmap_migration.sh rollback
    ./cmd/skm/1.mu_skm_migration.sh handle
    ./cmd/skm/2.mu_skm_configmap_migration.sh handle
}

Migration_mvp2_service_svcskm() {
    #9.4
    # ./cmd/skm/3.business_skm_upgrade.sh rollback
    # ./cmd/skm/4.business_skm_management.sh rollback
    ./cmd/skm/3.business_skm_upgrade.sh handle
    ./cmd/skm/4.business_skm_management.sh handle
}

Migration_mvp2_service_cod() {
    #9.5
    cd ${Cmd_dir2}
    # ./cmd/cod/cod_migration.sh rollback
    ./cmd/cod/cod_migration.sh handle

}

Migration_mvp2_service_prc() {
    #9.6
    cd ${Cmd_dir2}
    ./cmd/prc/prc_migration.sh handle
    # ./cmd/prc/prc_migration.sh rollback
}

Migration_mvp2_service_soc() {
    #9.7
    cd ${Cmd_dir2}
    # ./cmd/soc/soc_migration.sh rollback
    ./cmd/soc/soc_migration.sh handle

}
Migration_mvp2_service_automation() {
    #9.10
    cd ${Cmd_dir2}
    # ./cmd/automation/automation_migration.sh rollback
    ./cmd/automation/automation_migration.sh handle

}
Migration_mvp2_service_environment() {
    #9.11
    cd ${Cmd_dir2}
    ./cmd/environment/environment_migration.sh rollback
    ./cmd/environment/environment_migration.sh handle

}

Migration_mvp2_service_monitoring() {
    #9.12
    cd ${Cmd_dir2}
    # ./cmd/monitoring/1.monitoring_migration.sh rollback
    ./cmd/monitoring/1.monitoring_migration.sh handle
}

Migration_mvp1_mudb_mvp2() {
    mu1_db_user=opsroot
    mu1_db_pass=${mu_pwd}
    mu1_db_host=${mvp1_db_host}
    mu2_db_host=${mvp2_db_host}
    mu1_db_port=3306
    mu1_db_list="
apigov
automation
cod-vmware
datagov
db_prc
skm
soc
specmgmt
upm
vault
"
    rm -fr mu1_db_backup
    mkdir -p mu1_db_backup

    migration::log::info "mu db info ${mu1_db_host},${mu2_db_host},${mu_pwd}"

    # update mvp1 automation

    for db in $mu1_db_list; do
        mysqldump --set-gtid-purged=OFF -u$mu1_db_user -p$mu1_db_pass -h$mu1_db_host $db >mu1_db_backup/${db}_data.sql
    done
    # set upm user read only.
    mysql -u$mu1_db_user -p$mu1_db_pass -h$mu1_db_host <./mvp1sql/3_upm.sql

    # tar zcf ../mu1_db_backup.tgz mu1_db_backup && rm -fr mu1_db_backup
    echo "$(basename $0). Backup mvp1 db success..."

    for db in $mu1_db_list; do
        mysql -u$mu1_db_user -p$mu1_db_pass -h$mu2_db_host -e 'DROP DATABASE IF EXISTS `'${db}'_mu1`;'
        mysql -u$mu1_db_user -p$mu1_db_pass -h$mu2_db_host -e 'CREATE DATABASE `'${db}'_mu1`;'
        mysql -u$mu1_db_user -p$mu1_db_pass -h$mu2_db_host ${db}_mu1 <mu1_db_backup/${db}_data.sql
    done
    mysql -u$mu1_db_user -p$mu1_db_pass -h$mu2_db_host <./mvp1sql/2_automation.sql

    echo "$(basename $0). Import mvp1 to mvp2 db success..."

}

  Upgrade_res_agent() {
    if [ ! -z "${ems_list}" ]; then
        migration::log::info "start upgrade ems..."
        Upgrade_prc_agent "ebo" "${ems_list}"
        Get_Status $?
    fi

    if [ ! -z "${dos_list}" ]; then
        migration::log::info "start upgrade dos..."
        Upgrade_prc_agent "dbor" "${dos_list}"
        Get_Status $?
    fi

    if [ ! -z "${rbo_list}" ]; then
        migration::log::info "start upgrade rbo..."
        Upgrade_prc_agent "rbo" "${rbo_list}"
        Get_Status $?
    fi
}

rollback_all_upgrade_services() {
    cd ${Cmd_dir2}
    ./cmd/upm/upm_migration.sh rollback_upgrade_services
    ./cmd/upm/upm_migration.sh rollback
    ./cmd/workspace/workspace_migration.sh rollback
    ./cmd/monitoring/2.monitoring_configmap_migration.sh rollback
    ./cmd/skm/1.mu_skm_migration.sh rollback
    ./cmd/skm/2.mu_skm_configmap_migration.sh rollback
    ./cmd/skm/3.business_skm_upgrade.sh rollback
    ./cmd/skm/4.business_skm_management.sh rollback
    ./cmd/cod/cod_migration.sh rollback
    ./cmd/prc/prc_migration.sh rollback
    ./cmd/soc/soc_migration.sh rollback
    ./cmd/automation/automation_migration.sh rollback
    ./cmd/environment/environment_migration.sh rollback
    ./cmd/monitoring/1.monitoring_migration.sh rollback
    ./cmd/environment/environment_migration.sh rollback
    ./cmd/monitoring/1.monitoring_migration.sh rollback
}