#!/bin/bash

name=multiverse
version=2.0.0
chartfile=$name/Chart.yaml

# get new version
function get_new_version() {
  if [ ! -d $name ]; then
    mkdir -p $name/charts
  fi

  if [ -f $name/Chart.yaml ]; then
    getversion=$(helm show chart $name | sed -n 's/^version: //p')
    if [[ $getversion =~ ([0-9]+)$ ]]; then
      last_digits="${BASH_REMATCH[1]}"
      # 对数字部分加 1
      new_last_digits=$((last_digits + 1))
      # 替换原版本号中的数字部分为新的数字
      new_version="${getversion%$last_digits}$new_last_digits"
      echo "原始版本号: $getversion"
      echo "新版本号: $new_version"
      version=$new_version
      sed -i 's/^version=.*$/version='$version'/' $0
    else
      echo "无法提取版本号中的数字部分"
      exit 9
    fi
  fi
  echo "multiverse目录为空，设置初始版本号: $version"
}

# copy values.yaml
function copy_values() {
  cp -a values-global-example.yaml $name/values.yaml
}

# create Chart.yaml
function gen_chartyaml() {
  >$chartfile
  cat >>$chartfile <<EOF
apiVersion: v1
name: $name
version: $version
dependencies:
EOF

  for n in environment soc-job statusmgmt-logalert statusmgmt-rsquery workspace organization statusmgmt-alertmgmt statusmgmt-logmgmt mu-aig organization-spj statusmgmt-apmlogmgmt statusmgmt-metricalert upmbss00 automation mu-web-mvp2 prc statusmgmt-applogmgmt statusmgmt-monitor upmbss01 cpc skm statusmgmt-asquery statusmgmt-rsm upmdas01; do
    showchart=$(helm show chart $n)
    cat >>$chartfile <<EOF
- name: $(echo $(echo "$showchart" | sed -n 's/^name: //p'))
  repository: file://../$n
  version: $(echo $(echo "$showchart" | sed -n 's/^version: //p'))
  tags: [$(echo $(echo "$showchart" | sed -n 's/^appVersion: //p'))]
EOF
  done
}

# gen charts/
function gen_charts() {
  helm dependency build $name
}

# main
get_new_version
copy_values
gen_chartyaml
gen_charts
