CREATE TABLE `e_alert_channel_configuration` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `env` varchar(100) NOT NULL,
  `channel_id` int(11) NOT NULL,
  `host` varchar(100) NOT NULL,
  `port` int(11) NOT NULL,
  `user` varchar(255) NOT NULL,
  `password` varchar(255) NOT NULL,
  `create_time` datetime DEFAULT CURRENT_TIMESTAMP,
  `creator_id` varchar(255) NOT NULL DEFAULT 'system',
  `update_time` datetime DEFAULT CURRENT_TIMESTAMP,
  `updator_id` varchar(255) NOT NULL DEFAULT 'system',
  `tls` int(11) NOT NULL DEFAULT '0',
  `template` text NOT NULL,
  `optional_items` text,
  `is_normal_template` tinyint(1) NOT NULL DEFAULT '1',
  `status` tinyint(1) DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `env_channel` (`env`,`channel_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

CREATE TABLE `e_alert` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `create_time` datetime DEFAULT CURRENT_TIMESTAMP,
  `creator_id` varchar(255) NOT NULL DEFAULT '0' ,
  `update_time` datetime DEFAULT CURRENT_TIMESTAMP ,
  `updator_id` varchar(255) NOT NULL DEFAULT '0' ,
  `org` varchar(50) NOT NULL,
  `az` varchar(50) NOT NULL,
  `workspace_id` varchar(50) NOT NULL,
  `env` varchar(50) NOT NULL,
  `su` varchar(50) NOT NULL,
  `type` varchar(10) NOT NULL,
  `rule_type` varchar(10) NOT NULL,
  `target` varchar(600) NOT NULL,
  `name` varchar(255) NOT NULL,
  `level` varchar(10) NOT NULL,
  `labels` varchar(1000) NOT NULL,
  `msg` text NOT NULL,
  `rule_id` int(11) DEFAULT NULL,
  `value` text,
  `count` int(11) NOT NULL,
  `alert_id` varchar(20) DEFAULT NULL,
  `uuid` varchar(500) NOT NULL,
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `uuid` (`uuid`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC;

CREATE TABLE `e_alert_channel` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(100) NOT NULL,
  `type` varchar(100) NOT NULL,
  `description` varchar(255) DEFAULT NULL,
  `create_time` datetime DEFAULT CURRENT_TIMESTAMP,
  `creator_id` varchar(255) NOT NULL DEFAULT 'system',
  `update_time` datetime DEFAULT CURRENT_TIMESTAMP,
  `updator_id` varchar(255) NOT NULL DEFAULT 'system',
  `attr` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `name` (`name`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4;

CREATE TABLE `e_alert_detail` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `alert_key` varchar(255) NOT NULL,
  `target` varchar(255) DEFAULT NULL,
  `first_time` datetime DEFAULT CURRENT_TIMESTAMP COMMENT 'first time',
  `last_time` datetime DEFAULT CURRENT_TIMESTAMP COMMENT 'last time',
  `message` text COMMENT 'message',
  `count` int(11) NOT NULL DEFAULT '1',
  `msg_md5` varchar(64) DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `key_msg` (`alert_key`,`target`,`msg_md5`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC;

CREATE TABLE `e_alert_enum` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `create_time` datetime DEFAULT CURRENT_TIMESTAMP ,
  `creator_id` varchar(255) NOT NULL DEFAULT '0' ,
  `update_time` datetime DEFAULT CURRENT_TIMESTAMP ,
  `updater_id` varchar(255) NOT NULL DEFAULT '0' ,
  `type` varchar(255) DEFAULT NULL COMMENT 'type',
  `name` varchar(255) DEFAULT '',
  `key` varchar(255) DEFAULT '',
  `value` text,
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `name_unique` (`type`,`name`,`key`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC;

CREATE TABLE `e_alert_history` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `create_time` datetime DEFAULT CURRENT_TIMESTAMP ,
  `creator_id` varchar(50) NOT NULL DEFAULT '0' ,
  `update_time` datetime DEFAULT CURRENT_TIMESTAMP ,
  `updator_id` varchar(50) NOT NULL DEFAULT '0' ,
  `org` varchar(20) NOT NULL,
  `az` varchar(20) NOT NULL,
  `workspace_id` varchar(20) NOT NULL,
  `env` varchar(20) NOT NULL,
  `su` varchar(20) NOT NULL,
  `type` varchar(10) NOT NULL,
  `rule_type` varchar(10) NOT NULL,
  `target` varchar(500) NOT NULL,
  `name` varchar(255) NOT NULL,
  `level` varchar(10) NOT NULL,
  `labels` varchar(1000) NOT NULL,
  `msg` varchar(500) NOT NULL,
  `rule_id` int(11) DEFAULT NULL,
  `value` text,
  `count` int(11) NOT NULL,
  `alert_id` varchar(20) DEFAULT NULL,
  `uuid` varchar(500) NOT NULL,
  `reason` varchar(1000) DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `uuid` (`uuid`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC;

CREATE TABLE `e_alert_rule_template` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `workspace_id` varchar(30) DEFAULT NULL,
  `env_id` varchar(30) DEFAULT NULL,
  `rule_type` varchar(20) NOT NULL,
  `alert_type` varchar(20) NOT NULL,
  `alert_field` varchar(50) NOT NULL,
  `expression` text,
  `level` varchar(20) NOT NULL,
  `period` varchar(20) NOT NULL,
  `frequency` varchar(20) NOT NULL,
  `count` int(11) NOT NULL,
  `create_time` datetime DEFAULT CURRENT_TIMESTAMP,
  `creator_id` varchar(255) NOT NULL DEFAULT 'system',
  `update_time` datetime DEFAULT CURRENT_TIMESTAMP,
  `updator_id` varchar(255) NOT NULL DEFAULT 'system',
  `status` tinyint(255) NOT NULL DEFAULT '1',
  `org` varchar(255) DEFAULT NULL,
  `recover_count` int(11) NOT NULL DEFAULT '3',
  `unit` varchar(50) DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `expression` (`rule_type`,`alert_type`,`alert_field`,`level`,`workspace_id`,`env_id`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4;

CREATE TABLE `e_alert_strategy` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `org` varchar(50) DEFAULT 'common',
  `workspace_id` varchar(50) DEFAULT 'common' COMMENT 'workspace_id',
  `env_id` varchar(50) DEFAULT 'common' COMMENT 'Env ID',
  `name` varchar(100) NOT NULL,
  `type` varchar(20) NOT NULL,
  `target` text,
  `rules` varchar(255) DEFAULT NULL,
  `status` tinyint(1) NOT NULL DEFAULT '1',
  `description` varchar(255) DEFAULT NULL,
  `channel` varchar(20) NOT NULL,
  `receivers` text,
  `start_time` varchar(10) DEFAULT NULL,
  `end_time` varchar(10) DEFAULT NULL,
  `create_time` datetime DEFAULT CURRENT_TIMESTAMP,
  `creator_id` varchar(255) NOT NULL DEFAULT 'system',
  `update_time` datetime DEFAULT CURRENT_TIMESTAMP,
  `updator_id` varchar(255) NOT NULL DEFAULT 'system',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uniqname` (`org`,`workspace_id`,`env_id`,`name`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4;

CREATE TABLE `e_alert_rule` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `workspace_id` varchar(30) DEFAULT NULL,
  `env_id` varchar(30) DEFAULT NULL,
  `rule_type` varchar(20) NOT NULL,
  `alert_type` varchar(20) NOT NULL,
  `alert_field` varchar(20) NOT NULL,
  `expression` text,
  `level` varchar(20) NOT NULL,
  `period` varchar(20) NOT NULL,
  `frequency` varchar(20) NOT NULL,
  `count` int(11) NOT NULL,
  `create_time` datetime DEFAULT CURRENT_TIMESTAMP,
  `creator_id` varchar(255) NOT NULL DEFAULT 'system',
  `update_time` datetime DEFAULT CURRENT_TIMESTAMP,
  `updator_id` varchar(255) NOT NULL DEFAULT 'system',
  `status` tinyint(255) NOT NULL DEFAULT '1',
  `org` varchar(255) DEFAULT NULL,
  `recover_count` int(11) NOT NULL DEFAULT '3',
  `unit` varchar(50) DEFAULT NULL,
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4;

CREATE TABLE `e_alert_user` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(20) NOT NULL,
  `telphone` varchar(20) NOT NULL,
  `email` varchar(255) DEFAULT NULL,
  `source` varchar(20) NOT NULL,
  `tenant_id` bigint(20) NOT NULL,
  `create_time` datetime DEFAULT CURRENT_TIMESTAMP,
  `creator_id` varchar(255) NOT NULL DEFAULT 'system',
  `update_time` datetime DEFAULT CURRENT_TIMESTAMP,
  `updator_id` varchar(255) NOT NULL DEFAULT 'system',
  PRIMARY KEY (`id`) USING BTREE,
  UNIQUE KEY `unicName` (`name`,`tenant_id`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4;
