
CREATE TABLE `skm_key` (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `service_id` varchar(50) NOT NULL,
    `system_type` varchar(55) NOT NULL,
    `key_type` varchar(50) NOT NULL,
    `key_version` int(11) NOT NULL,
    `key_id` varchar(50) NOT NULL,
    `key_value` MEDIUMBLOB NOT NULL,
    `state` int(1) NOT NULL,
    `effect_time` varchar(30) NOT NULL,
    `expire_time` varchar(30) NOT NULL,
    `creator` varchar(50) DEFAULT NULL,
    `create_time` varchar(50) DEFAULT NULL,
    `modifier` varchar(50) DEFAULT NULL,
    `last_update` varchar(50) DEFAULT NULL,
    `deleted_at` VARCHAR(45) NULL,
    `is_deleted` INT(1) NOT NULL DEFAULT 0,
    `description` varchar(512) DEFAULT NULL,
    `workspace_id` varchar(128) DEFAULT NULL,
    `environment_id` varchar(128) DEFAULT NULL,
    PRIMARY KEY (`id`) USING BTREE,
    UNIQUE INDEX `key_idx` (`service_id` ASC,`system_type` ASC,`key_type` ASC,`key_version` ASC,`workspace_id` ASC,`environment_id` ASC),
    INDEX `service_id_idx` (`service_id` ASC)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE `skm_service_id` (
    `service_id` varchar(50) NOT NULL,
    `system_type` varchar(55) NOT NULL,
    `key_type` varchar(50) NOT NULL,
    PRIMARY KEY (`service_id`,`system_type`,`key_type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;



CREATE TABLE `skm_um_permission` (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `api` varchar(64) NOT NULL,
    `rules` text NOT NULL,
    `created` datetime NOT NULL,
    `updated` datetime NOT NULL,
    PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE `skm_certificate` (
    `cert_id` varchar(50) NOT NULL,
    `cert_name` varchar(200) NOT NULL,
    `cert_type` varchar(2) NOT NULL,
    `cert_txt` text NOT NULL,
    `private_key` text NOT NULL,
    `domain` varchar(100) NOT NULL,
    `expire_time` varchar(45) NOT NULL,
    `creator` varchar(50) DEFAULT NULL,
    `create_time` varchar(45) DEFAULT NULL,
    `modifier` varchar(50) DEFAULT NULL,
    `last_update` varchar(45) DEFAULT NULL,
    `deleted_at` VARCHAR(45) NULL,
    `is_deleted` INT(1) NOT NULL DEFAULT 0,
    `workspace_id` varchar(128) DEFAULT NULL,
    `environment_id` varchar(128) DEFAULT NULL,
    PRIMARY KEY (`cert_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE `skm_pki` (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `private_key` text,
    `private_key_param` varchar(45) DEFAULT NULL,
    `private_key_algorithm` varchar(45) DEFAULT NULL,
    `signature_algorithm` varchar(45) DEFAULT NULL,
    `cert` text,
    `is_ca` tinyint(4) DEFAULT NULL,
    `parent_id` int(11) DEFAULT NULL,
    `not_before` varchar(45) DEFAULT NULL,
    `not_after` varchar(45) DEFAULT NULL,
    `creator` varchar(50) DEFAULT NULL,
    `create_time` varchar(50) DEFAULT NULL,
    `modifier` varchar(50) DEFAULT NULL,
    `last_update` varchar(50) DEFAULT NULL,
    `deleted_at` VARCHAR(45) NULL,
    `is_deleted` INT(1) NOT NULL DEFAULT 0,
    `workspace_id` varchar(128) DEFAULT NULL,
    `environment_id` varchar(128) DEFAULT NULL,
    PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;



CREATE TABLE `skm_pki_owner` (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `cert_id` int(11) DEFAULT NULL,
    `owner` varchar(45) DEFAULT NULL,
    `creator` varchar(50) DEFAULT NULL,
    `create_time` varchar(50) DEFAULT NULL,
    `modifier` varchar(50) DEFAULT NULL,
    `last_update` varchar(50) DEFAULT NULL,
    PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;



CREATE TABLE `skm_revoked_pki` (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `cert_id` int(11) DEFAULT NULL,
    `revoke_time` varchar(45) DEFAULT NULL,
    `revoke_reason` varchar(255) DEFAULT NULL,
    `creator` varchar(50) DEFAULT NULL,
    `create_time` varchar(50) DEFAULT NULL,
    `modifier` varchar(50) DEFAULT NULL,
    `last_update` varchar(50) DEFAULT NULL,
    PRIMARY KEY (`id`),
    UNIQUE INDEX `idx_cert_id` (`cert_id` ASC)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE `skm_secret` (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `service_id` varchar(50) NOT NULL,
    `key` varchar(200) NOT NULL,
    `secret_value` MEDIUMBLOB DEFAULT NULL,
    `vault_key` varchar(200) NOT NULL,
    `creator` varchar(50) DEFAULT NULL,
    `description` VARCHAR(128) DEFAULT NULL,
    `create_time` varchar(45) DEFAULT NULL,
    `modifier` varchar(50) DEFAULT NULL,
    `last_update` varchar(45) DEFAULT NULL,
    `deleted_at` VARCHAR(45) NULL,
    `is_deleted` INT(1) NOT NULL DEFAULT 0,
    `workspace_id` varchar(128) DEFAULT NULL,
    `environment_id` varchar(128) DEFAULT NULL,
    PRIMARY KEY (`id`),
    UNIQUE INDEX `idx_service_key` (`service_id` ASC,`key` ASC,`deleted_at` ASC,`workspace_id` ASC,`environment_id` ASC)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE `skm_config` (
    `key` varchar(200) NOT NULL,
    `key_id` varchar(50) DEFAULT NULL,
    `key_value` MEDIUMBLOB DEFAULT NULL,
    `create_time` varchar(50) DEFAULT NULL,
    `creator` varchar(50) DEFAULT NULL,
    `modifier` varchar(50) DEFAULT NULL,
    `last_update` varchar(50) DEFAULT NULL,
    PRIMARY KEY (`key`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE `skm_digital_certificate` (
    `id` varchar(40) NOT NULL,
    `cert_serial_number` varchar(45) NOT NULL,
    `cert_name` varchar(45) NOT NULL,
    `description` varchar(500) DEFAULT NULL,
    `cert_type` varchar(10) NOT NULL,
    `cert_content` text NOT NULL,
    `private_pem` text,
    `cert_issuer_cn` varchar(500) DEFAULT NULL,
    `cert_subject_cn` varchar(500) DEFAULT NULL,
    `cert_dnss` text,
    `cert_ips` text,
    `cert_not_before` varchar(60) DEFAULT NULL,
    `cert_not_after` varchar(60) DEFAULT NULL,
    `creator` varchar(50) DEFAULT NULL,
    `create_time` varchar(50) DEFAULT NULL,
    `modifier` varchar(50) DEFAULT NULL,
    `last_update` varchar(50) DEFAULT NULL,
    `deleted_at` varchar(50) DEFAULT NULL,
    `is_deleted` int(1) DEFAULT '0',
    `workspace_id` varchar(128) DEFAULT NULL,
    `environment_id` varchar(128) DEFAULT NULL,
    PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE `skm_service_lock`
(
    `id`          int(20) NOT NULL AUTO_INCREMENT,
    `lock_type`   int(1) NOT NULL,
    `lock_status` int(1),
    `create_time` varchar(64) default null,
    PRIMARY KEY (`id`),
    UNIQUE INDEX `idx_service_lock` (`lock_type` ASC,`lock_status` ASC)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- ----------------------------
-- Table structure for skm_hsm_key
-- ----------------------------

CREATE TABLE `skm_hsm_key` (
   `id` bigint NOT NULL AUTO_INCREMENT,
   `key_type` int DEFAULT NULL COMMENT '0:PinKeyEncryptKey 1:MacKeyEncryptKey 2:DataKeyEncryptKey 3:OutgoingStaticPinKey',
   `key_format` int DEFAULT NULL,
   `key_data` text,
   `hsm_type` int DEFAULT NULL,
   `status` int DEFAULT NULL,
   `created_at` varchar(255) DEFAULT NULL,
   `updated_at` varchar(255) DEFAULT NULL,
   `deleted_at` varchar(255) DEFAULT NULL,
   `workspace_id` varchar(255) DEFAULT NULL,
   `environment_id` varchar(255) DEFAULT NULL,
   PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- ----------------------------
-- Table structure for skm_hsm_working_key
-- ----------------------------

CREATE TABLE `skm_hsm_working_key` (
   `id` bigint NOT NULL AUTO_INCREMENT,
   `key_count` int DEFAULT NULL,
   `key_type` int DEFAULT NULL COMMENT '0:PIN KEY 1:MAC KEY 2:DATA KEY',
   `key_format` int DEFAULT NULL,
   `key_data` text,
   `key_direction` int DEFAULT NULL COMMENT '0:Outbound messages only 1:Inbound messages only 2:Inbound&Outbound',
   `variant_key_data` varchar(255) DEFAULT NULL,
   `check_digits` varchar(255) DEFAULT NULL,
   `transaction_id` varchar(255) DEFAULT NULL,
   `hsm_type` int DEFAULT NULL,
   `status` int DEFAULT NULL,
   `created_at` varchar(255) DEFAULT NULL,
   `updated_at` varchar(255) DEFAULT NULL,
   `deleted_at` varchar(255) DEFAULT NULL,
   `workspace_id` varchar(255) DEFAULT NULL,
   `environment_id` varchar(255) DEFAULT NULL,
   PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
