
{{- define "sts.sedImage" -}}
{{- $registryName := .Values.sed.image.registry -}}
{{- $repositoryName := .Values.sed.image.repository -}}
{{- $tag := .Values.sed.image.tag | toString -}}
{{- printf "%s/%s:%s" $registryName $repositoryName $tag -}}
{{- end -}}


{{- define "sts.skmImage" -}}
{{- $registryName := .Values.skm.image.registry -}}
{{- $repositoryName := .Values.skm.image.repository -}}
{{- $tag := default "" .Values.skm.image.tag | toString -}}
{{- if ne $tag "" }}
{{- printf "%s/%s:%s" $registryName $repositoryName $tag -}}
{{- else }}
{{- printf "%s/%s:%s" $registryName $repositoryName .Chart.AppVersion -}}
{{- end -}}
{{- end -}}

{{- define "sts.vaultImage" -}}
{{- $registryName := .Values.vault.image.registry -}}
{{- $repositoryName := .Values.vault.image.repository -}}
{{- $tag := default "" .Values.vault.image.tag | toString -}}
{{- if ne $tag "" }}
{{- printf "%s/%s:%s" $registryName $repositoryName $tag -}}
{{- else }}
{{- printf "%s/%s:%s" $registryName $repositoryName .Chart.AppVersion -}}
{{- end -}}
{{- end -}}

{{- define "common.initContainers" -}}
- name: init-dir
  image: hub.multiverse.io/library/busybox
  envFrom:
  - configMapRef:
      name: {{ .Values.vault.config.vault_token_configmap_name }}
  command:
  - 'sh'
  - '-ec'
  args:
  - |
    chown 1000:1000 /data/logs
    chown 1000:1000 /data/sedlogs
    cp -f /tmp/config/* /mnt/config
    cd /mnt/config
    echo "debug: skm_token=$skm_token"
    if [ -n "$skm_token" ];then
      echo sed -i "s/PLEASE_REPLACE_SKM_TOKEN/$skm_token/" app.toml
      sed -i "s/PLEASE_REPLACE_SKM_TOKEN/$skm_token/" app.toml
    else
      echo "error: skm_token is empty"
      exit 1
    fi
  volumeMounts:
  - mountPath: /data/logs
    name: log-path
  - mountPath: /data/sedlogs
    name: sedlog-path
  - mountPath: /tmp/config
    name: config-skm
  - mountPath: /mnt/config
    name: share-config-skm
{{- end -}}